// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PRISON_VERSION_H
#define PRISON_VERSION_H

#define PRISON_VERSION_STRING "6.19.0"
#define PRISON_VERSION_MAJOR 6
#define PRISON_VERSION_MINOR 19
#define PRISON_VERSION_PATCH 0
#define PRISON_VERSION ((6<<16)|(19<<8)|(0))

#endif
